@@ -63,15 +63,11 @@ class Conllu:
                 tokens.append(token)
                 columns = token.keys()
                 if 'ID' in token and 'FORM' in columns:
-                    old_id = token['ID'] or ''
+                    old_id = token['ID']
                     if '.' in old_id:
                         sub_id += 1
                         token['ID'] = str(id_) + '.' + str(sub_id)
                     elif multi_token:
-                        #if '.' in old_id:
-                        #    sub_id += 1
-                        #    token['ID'] = str(id_) + '.' + str(sub_id)
-                        #else:
                         id_ += 1
                         sub_id = 0
                         token['ID'] = str(id_)
@@ -118,6 +114,10 @@ class Conllu:
                         else:
                             sub_id += 1
                             token['ID'] = str(id_) + '.' + str(sub_id)
+                    if token['ID'] != old_id:
+                        for token_ in sentence:
+                            if token_['HEAD'] == old_id:
+                                token_['HEAD'] = token['ID']
             sentence = tokens
             if not sentence:
                 vals = {}
@@ -288,14 +288,14 @@ class Conllu:
                         if column in ['FEATS', 'MISC']:
                             try:
                                 val = OrderedDict(
-                                    () if val == '_' else
-#                                        or val.startswith ('_|') else
+                                    () if val == '_'
+                                       or val.startswith ('_|') else
                                     [(k, v) for k, v in [
                                         t.split('=', 1) for t in val.split('|')
                                     ]])
                             except ValueError as e:
                                 print('ERROR when loading Conllu (line {})'
-                                          .format(line_no), sys.stderr)
+                                          .format(line_no + 1), sys.stderr)
                                 print(line, sys.stderr)
                                 print(column, sys.stderr)
                                 print(val, sys.stderr)
